@@ -131,65 +131,68 @@ class GitIssuePublisher(Publisher):
 
     def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
         """
-        Appends adherence data to the existing comment body as a chart.
+        Appends adherence data to the existing comment body using an XY diagram with emojis.
 
         :param existing_body: The existing comment body.
         :param adherence: A dictionary with adherence score details.
         :return: The updated comment body.
         """
-        # Extract existing scores from the current body
-        scores_history = self.extract_scores(existing_body)
+        # Extract existing data points from the comment
+        data_points = self.extract_data_points(existing_body)
+        data_points.append((self.sha[:7], adherence['score'], adherence['emoji']))
 
-        # Append the new score
-        scores_history.append((self.sha, adherence['score']))
+        # Generate the new XY diagram
+        xy_diagram = self.generate_xy_diagram(data_points)
 
-        # Generate the new chart
-        score_chart = self.generate_score_chart(scores_history)
-
-        # Update the comment with the new chart
-        updated_body = existing_body.replace(
-            "\n**Adherence Scores History:**\n",
-            f"\n**Adherence Scores History:**\n{score_chart}\n"
-        )
+        # Update the comment with the new diagram
+        updated_body = existing_body.split("\n**Adherence Scores History:**")[0]
+        updated_body += "\n**Adherence Scores History:**\n" + xy_diagram
         return updated_body
 
-    def generate_score_chart(self, scores_history: List[tuple]) -> str:
+    def generate_xy_diagram(self, data_points: List[tuple]) -> str:
         """
-        Generates a simple ASCII chart for the adherence scores.
+        Generates a simple XY diagram using emojis as data points.
 
-        :param scores_history: A list of tuples containing commit SHAs and scores.
-        :return: A string representing the ASCII chart.
+        :param data_points: A list of tuples containing commit SHAs, scores, and emojis.
+        :return: A string representing the XY diagram.
         """
-        max_score = max(score for _, score in scores_history)
-        chart = ["Adherence Score Chart\n"]
+        max_score = max(score for _, score, _ in data_points)
+        diagram = ["```\n    +---+---+---+---+---+---+---+---+---+---+---+ (Score)"]
+        for i in range(max_score, 0, -1):
+            line = f"{str(i).rjust(2)} | " + ''.join(
+                data_point[2] if data_point[1] >= i else '   '
+                for data_point in sorted(data_points, key=lambda x: x[1])
+            )
+            diagram.append(line)
+        diagram.append("    +---+---+---+---+---+---+---+---+---+---+---+\n")
+        diagram.append("       " + "   ".join(dp[0] for dp in sorted(data_points, key=lambda x: x[1])) + " (SHA)")
+        diagram.append("```")
+        return '\n'.join(diagram)
 
-        for sha, score in scores_history:
-            bar = '*' * (score * 10 // max_score)
-            chart.append(f"{sha[:7]}: {bar} ({score})")
-
-        return '\n'.join(chart)
-
-    def extract_scores(self, body: str) -> List[tuple]:
+    def extract_data_points(self, body: str) -> List[tuple]:
         """
-        Extracts the adherence scores from the comment body.
+        Extracts data points from the comment body.
 
         :param body: The comment body.
-        :return: A list of tuples with commit SHAs and scores.
+        :return: A list of tuples with commit SHAs, scores, and emojis.
         """
-        lines = body.splitlines()
-        scores_history = []
-
+        lines = body.split("\n")
+        data_points = []
+        start_extracting = False
         for line in lines:
-            if line.startswith("**Adherence Scores History:**"):
+            if line.strip().startswith("+---"):  # Start of the diagram
+                start_extracting = True
                 continue
-            if line.strip() and ':' in line:
-                parts = line.split(': ')
-                sha = parts[0].strip()
-                score_part = parts[1].strip().split(' ')
-                score = int(score_part[-1].strip('()'))
-                scores_history.append((sha, score))
-
-        return scores_history
+            if start_extracting:
+                if line.strip().startswith("```"):  # End of the diagram
+                    break
+                parts = line.split('|')
+                if len(parts) > 2:  # Data point lines
+                    sha_part = parts[0].strip()
+                    for idx, part in enumerate(parts[1:], 1):
+                        if part.strip():  # Contains an emoji
+                            data_points.append((sha_part, idx, part.strip()))
+        return data_points
     
 
 class WebPublisher(Publisher):
